<script setup>
import AdminAuthenticatedLayout from '@/Layouts/AdminAuthenticatedLayout.vue';
import InputError from '@/Components/InputError.vue';
import InputLabel from '@/Components/InputLabel.vue';
import PrimaryButton from '@/Components/PrimaryButton.vue';
import TextInput from '@/Components/TextInput.vue';
import NavLink from '@/Components/NavLink.vue';
import { Head, useForm, usePage } from '@inertiajs/vue3';
import { ref } from 'vue';

defineProps({
    status: {
        type: String,
    },
});

const user = usePage().props.user;
const { data, reset } = usePage();
const flashMessage = ref('');

const form = useForm({
    id: user.id,
    name: user.name,
    email: user.email,
    company: user.company,
    address1: user.address1,
    address2: user.address2,
    city: user.city,
    state: user.state,
    postal: user.postal,
    country: user.country,
    phone: user.phone,
    fax: user.fax,
});

const submit = () => {
    const userID = user.id;

    form.post(route('admin.user.update',{id: userID}), {
        onSuccess: () => {
            flashMessage.value = "User updated successfully!";
        },
        onError: (error) => {
            console.error(error);
        }
    });
};
</script>

<template>

    <Head title="Edit User" />

    <AdminAuthenticatedLayout>

        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Edit User</h2>
        </template>

        <div class="py-12">
            <div class="max-w-7xl mx-auto sm:px-6 lg:px-8">
                <form @submit.prevent="submit">
                    <div v-if="flashMessage" class="font-bold text-green-600">
                        <div class="form-row px-8">
                            <div class="col-md-6">
                                <h4>{{ flashMessage }}</h4>
                            </div>
                        </div>
                    </div>
                    <input type="hidden" id="id" v-model="form.id" />
                    <div class="form-row px-8">
                        <div class="mt-4 col-md-6">
                            <InputLabel for="name" value="Name" />

                            <TextInput
                                id="name"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.name"
                                required
                                autofocus
                                autocomplete="name"
                            />

                            <InputError class="mt-2" :message="form.errors.name" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="email" value="Email" />

                            <TextInput
                                id="email"
                                type="email"
                                class="mt-1 block w-full"
                                v-model="form.email"
                                required
                                autocomplete="username"
                            />

                            <InputError class="mt-2" :message="form.errors.email" />
                        </div>

                        <div class="mt-4 col-md-12">
                            <InputLabel for="company" value="Company" />

                            <TextInput
                                id="company"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.company"
                                required
                                autofocus
                                autocomplete="company"
                            />

                            <InputError class="mt-2" :message="form.errors.company" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="address1" value="Address1 (Primary)" />

                            <TextInput
                                id="address1"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.address1"
                                required
                                autofocus
                                autocomplete="address1"
                            />

                            <InputError class="mt-2" :message="form.errors.address1" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="address2" value="Address2" />

                            <TextInput
                                id="address2"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.address2"
                                required
                                autofocus
                                autocomplete="address2"
                            />

                            <InputError class="mt-2" :message="form.errors.address2" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="city" value="City" />

                            <TextInput
                                id="city"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.city"
                                required
                                autofocus
                                autocomplete="city"
                            />

                            <InputError class="mt-2" :message="form.errors.city" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="state" value="State" />

                            <TextInput
                                id="state"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.state"
                                required
                                autofocus
                                autocomplete="state"
                            />

                            <InputError class="mt-2" :message="form.errors.state" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="postal" value="Zip/Postal Code" />

                            <TextInput
                                id="postal"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.postal"
                                required
                                autofocus
                                autocomplete="postal"
                            />

                            <InputError class="mt-2" :message="form.errors.postal" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="country" value="Country" />

                            <TextInput
                                id="country"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.country"
                                required
                                autofocus
                                autocomplete="country"
                            />

                            <InputError class="mt-2" :message="form.errors.country" />
                        </div>

                        <div class="mt-4 col-12">
                            <NavLink :href="route('admin.users.addresses', { id: user.id })" :active="route().current('admin.users.addresses')">
                                <button class="btn bg-white">Multiple Addresses</button>
                            </NavLink>
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="phone" value="Phone Number" />

                            <TextInput
                                id="phone"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.phone"
                                required
                                autofocus
                                autocomplete="phone"
                            />

                            <InputError class="mt-2" :message="form.errors.phone" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="fax" value="Fax" />

                            <TextInput
                                id="fax"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.fax"
                                required
                                autofocus
                                autocomplete="fax"
                            />

                            <InputError class="mt-2" :message="form.errors.fax" />
                        </div>

                    </div>

                    <div class="flex items-center justify-end mt-4">
                        <PrimaryButton class="ms-4" :class="{ 'opacity-25': form.processing }" :disabled="form.processing">
                            Save User
                        </PrimaryButton>
                    </div>
                </form>
            </div>
        </div>
    </AdminAuthenticatedLayout>
</template>
